@@ -1172,7 +1172,7 @@ def initGraphic(window="$n0p"):
         _consoleWin.keypad(True)
         sys.stdout=n0out
         if window=="$n0p":
-            __SYSTEM_VARS__['__STDOUT__']=Log(1,1,*terminalSize)
+            __SYSTEM_VARS__['__STDOUT__']=Log(1,1,*terminalSize())
         else:
             if type(window)==Log:
                 __SYSTEM_VARS__['__STDOUT__']=window
